import { restResources, RestResources } from '@shopify/shopify-api/rest/admin/2023-07';
import { shopifyApi, ApiVersion } from '@shopify/shopify-api';
import { Session } from '@shopify/shopify-api';
export { restResources, RestResources, shopifyApi, ApiVersion, Session };
export declare const apiVersion = ApiVersion.July23;
export declare const sendEmails: boolean;
export declare const shipSpeedStandard = "Standard";
export declare const shipSpeedExpress = "Express";
export declare const shipSpeedPriority = "Priority";
export declare const validShipSpeeds: readonly ["Standard", "Express", "Priority"];
export declare const shopBlueDriverUS = "BlueDriver US";
export declare const shopBlueDriverCA = "BlueDriver CA";
export declare const shopAccutrade = "Accutrade";
export declare const shopAccutradeCA = "Accutrade CA";
export declare const shopGeneralBDMax = "BDMax";
export declare const fulfillmentInboundStatusShipped = "shipped";
export declare const fulfillmentInboundStatusPartial = "partial";
export declare const fulfillmentInboundStatusNew = "unshipped";
export declare const validFulfillmentStatuses: readonly ["unshipped", "partial", "shipped"];
export declare const fulfillmentOutboundStatusNew: null;
export declare const fulfillmentOutboundStatusComplete = "fulfilled";
export declare const fulfillmentOutboundStatusPartial = "partial";
export declare const fulfillmentOutboundStatusNA = "not_eligible";
export declare const validOutboundFUlfillmentStatuses: readonly ["fulfilled", "not_eligible", null, "partial"];
export declare const paymentStatusAuthoized = "authorized";
export declare const paymentStatusPending = "pending";
export declare const paymentStatusPaid = "paid";
export declare const paymentStatusPartiallyPaid = "partially_paid";
export declare const paymentStatusRefunded = "refunded";
export declare const paymentStatusVoided = "voided";
export declare const paymentStatusPartiallyRefunded = "partially_refunded";
export declare const paymentStatusAny = "any";
export declare const paymentStatusUnpaid = "unpaid";
export declare const validPaymentStatuses: readonly ["any", "authorized", "paid", "partially_paid", "partially_refunded", "pending", "refunded", "unpaid", "voided"];
export declare const orderStatusOpen = "open";
export declare const orderStatusclosed = "closed";
export declare const orderStatusCancelled = "cancelled";
export declare const orderStatusAny = "any";
export declare const validOrderStatuses: readonly ["open", "closed", "cancelled", "any"];
export declare const varIdBdMaxAnnual = 44284787949815;
export declare const varIdBdMaxMonthly = 44285022994679;
export declare const varIdBaas = 44201046835447;
export interface orderLookupFields {
    api_version: string;
    since_id?: number;
    fulfillment_status?: typeof validFulfillmentStatuses[number];
    financial_status?: typeof validPaymentStatuses[number];
    status: typeof validOrderStatuses[number];
}
export interface auth {
    [shopBlueDriverUS]: authDetails;
    [shopBlueDriverCA]: authDetails;
    [shopAccutrade]: authDetails;
    [shopAccutradeCA]: authDetails;
    [shopGeneralBDMax]: authDetails;
}
export interface authDetails {
    host: string;
    token: string;
    secret: string;
}
export declare const currencyCAD = "CAD";
export declare const currencyUSD = "USD";
export declare const validCurrencies: readonly ["CAD", "USD"];
export declare const countryUS = "US";
export declare const countryCanada = "CA";
export type validCountries = typeof countryCanada | typeof countryUS;
export declare const orderLookupNew = "new";
export declare const validOrderLookupTypes: readonly ["new"];
export declare const actionSave = "save";
export declare const actionClose = "close";
export declare const discountTargetItem = "items";
export declare const discountTargetShipping = "shipping";
export declare const discountTypeAbsolute = "absolute";
export declare const discountTypePercent = "percent";
export declare const tagFromSF = "From SF";
export declare enum sourceTypes {
    "shopify" = "web",
    "sub" = "subscription_contract"
}
export interface niceShopOrder {
    shopId?: string;
    created?: Date;
    currency?: typeof validCurrencies[number];
    orderNumber: string;
    orderStatusPage?: string;
    isTest?: boolean;
    discountCodes?: niceDiscount[];
    source?: sourceTypes | null;
    address: {
        firstName: string;
        lastName: string;
        name?: string;
        addressOne: string;
        addressTwo?: string | null;
        city: string;
        province: string;
        country: string;
        postalCode: string;
        phone?: null | string;
        email: string;
        company?: string | null;
    };
    items: shopOrderLine[];
    requestedShipping: typeof validShipSpeeds[number] | null;
    money: shopMonies;
    customerId: string;
    notes: string | null;
}
export declare const discountPercent = "percentage";
export declare const discountFixed = "fixed_amount";
export declare const discountShipping = "shipping";
export interface niceDiscount {
    title: string;
    amount: string;
    type: discountTypes;
}
export interface shopOrderLine {
    lineId?: string;
    qty: number;
    unitPrice: number;
    sku?: string;
    title: string;
    variantId: string;
    variantTitle: string;
}
export interface shopMonies {
    subTotal: number;
    tax: number;
    shipping: number;
    discount: number;
    total: number;
}
export declare const mandatoryAddressFields: string[];
export declare const mandatoryLineItemFields: string[];
export declare const mandatoryMoney: string[];
export declare const mandatoryTopLevelFields: string[];
export interface trackingDetailsInput {
    [pkgId: string]: {
        trackingNumber: string | null;
        carrier: string | null;
        url?: string;
        varIDs: string[];
        unshippable?: boolean;
    };
}
export interface shipmentDetailsForShopify {
    tracking: string | null;
    carrier: string | null;
    fulfillmentOrderIDs: string[];
    varIds: string[];
    isShippable: boolean;
    url?: string;
}
export interface trackingForShopify {
    [pkgId: string]: shipmentDetailsForShopify;
}
export interface productList {
    [key: string]: product;
}
export interface product {
    mainId: string;
    mainTitle: string;
    variantTitle: string;
    variantSKU: string;
    qty: number;
}
export type discountTypes = typeof discountPercent | typeof discountFixed | typeof discountShipping;
export interface discountApplication {
    target_type: string;
    type: string;
    value: string;
    value_type: discountTypes;
    allocation_method: string;
    target_selection: string;
    title: string;
}
export declare class fixedShopOrder extends restResources.Order {
    line_items: missingShopLineItem[];
    shipping_address: missingShippingAddress;
    shipping_lines: missingShippingLines[];
    total_shipping_price_set: shopMoneySet;
    discount_applications: discountApplication[];
    total_line_items_price_set: shopMoneySet;
    total_tax_set: shopMoneySet;
    total_discounts_set: shopMoneySet;
    total_price_set: shopMoneySet;
}
export interface missingShopLineItem {
    id?: number;
    quantity: number;
    price: string;
    price_set: shopMoneySet;
    sku?: string;
    title?: string;
    variant_id: number;
    variant_title?: string | null;
}
export interface missingShippingAddress {
    first_name: string | null;
    address1: string | null;
    phone?: string | null;
    city: string | null;
    zip: string | null;
    province?: string | null;
    country?: string | null;
    last_name: string | null;
    address2?: string | null;
    company?: string | null;
    latitude?: string | null;
    longitude?: string | null;
    name: string | null;
    country_code: string | null;
    province_code: string | null;
}
export interface missingShippingLines {
    id?: number;
    carrier_identifier?: string;
    code?: string;
    delivery_category?: string | null;
    discounted_price?: number;
    discounted_price_set?: shopMoneySet;
    phone?: string | null;
    price: string;
    price_set?: shopMoneySet;
    requested_fulfillment_service_id?: string | null;
    source?: string;
    title: string;
    tax_lines?: any[];
    discount_allocations?: any[];
    custom?: boolean;
}
export interface shopMoneySet {
    shop_money: {
        amount: string;
        currency_code: string;
    };
    presentment_money: {
        amount: string;
        currency_code: string;
    };
}
export interface fulfillmentIdLineItems {
    id: number;
    shop_id: number;
    fulfillment_order_id: number;
    quantity: number;
    line_item_id: number;
    inventory_item_id: number;
    fulfillable_quantity: number;
    variant_id: number;
}
