//@ts-nocheck
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as tanglyCases from './cases/complex.order.cases.js';
import * as shopConverter from '../shopify.conversions.js';
import * as shopConstants from '../shopify.constants.js';
import * as shopAPI from '../shopify.api.js';
import * as shopOrderMethods from '../shopify.orders.js';
import chai from 'chai';
chai.config.truncateThreshold = 0;
import chaiAsPromised from "chai-as-promised";
const expect = chai.expect;
chai.use(chaiAsPromised);
import * as dotenv from 'dotenv';
dotenv.config();
const isProduction = (process.env.NODE_ENV === 'PRODUCTION');
import HttpRequestMock from 'http-request-mock';
const mocker = HttpRequestMock.setup();
describe('Test complex order functions', () => __awaiter(void 0, void 0, void 0, function* () {
    before(() => __awaiter(void 0, void 0, void 0, function* () {
        //   mocker.get(/5413971558699.fulfillment_orders.json/, shopOrderCases.fulfillmetOrderResp, {status: 200});
        //   mocker.get(/123456789.fulfillment_orders.json/, shopOrderCases.fulfillmetOrderResp, {status: 200});
        //   mocker.get(/999.fulfillment_orders.json/, {"data": []}, {status: 200});        
        // mocker.post(/./, async (requestInfo: RequestInfo) => {console.log(util.inspect(requestInfo, {depth: null}));});
        shopAPI.setShopifySession(shopConstants.shopBlueDriverUS);
    }));
    after(() => __awaiter(void 0, void 0, void 0, function* () {
        mocker.reset();
    }));
    context('Test multi-item orders', () => __awaiter(void 0, void 0, void 0, function* () {
        it('Gets fulfillment IDs and filters out shipped line items', () => __awaiter(void 0, void 0, void 0, function* () {
            mocker.reset();
            mocker.get(/./, tanglyCases.twoItemFulfillmentTwoOpenOneNoShip.body);
            let results = yield shopOrderMethods.getUnshippedOrderFulfillmentIDs('5505340965111');
            const expected = {
                '44285022994679': { lineItemId: '13759061131511', fulfillmentOrderId: '6602711957751', qty: 2, isShippable: true },
                '44201046835447': { lineItemId: '13759061098743', fulfillmentOrderId: '6602711990519', qty: 2, isShippable: true },
                '55555555555': { lineItemId: '4156234165462155', fulfillmentOrderId: '666666', qty: 3, isShippable: false }
            };
            expect(results).to.deep.equal(expected);
        }));
        it('Doesnt try to close the order when no tracking is provided', () => __awaiter(void 0, void 0, void 0, function* () {
            mocker.reset();
            mocker.post(/./, (requestInfo) => __awaiter(void 0, void 0, void 0, function* () { throw new Error("die"); }));
            mocker.get(/./, (requestInfo) => __awaiter(void 0, void 0, void 0, function* () { throw new Error("die"); }));
            yield expect(shopOrderMethods.shipOrder('5505340965111', {})).not.to.be.rejected;
        }));
        it('Handles partial shipment, doesnt close the order', () => __awaiter(void 0, void 0, void 0, function* () {
            mocker.reset();
            mocker.get(/5505340965111.fulfillment_orders.json/, tanglyCases.twoItemFulfillmentTwoOpenOneNoShip.body);
            mocker.post(/close/, (requestInfo) => __awaiter(void 0, void 0, void 0, function* () { throw new Error("DIE"); }));
            mocker.post(/./, (requestInfo) => __awaiter(void 0, void 0, void 0, function* () {
                let expected = '{"fulfillment":{"line_items_by_fulfillment_order":[{"fulfillment_order_id":6602711957751}],"tracking_info":{"number":"fakenum1","company":"fakeCarrier1"},"notify_customer":true}}';
                if (requestInfo.body !== expected) {
                    throw new Error("Bad Body");
                }
                return { status: 201 };
            }));
            let firstItemTrack = {
                "1": {
                    trackingNumber: "fakenum1",
                    carrier: "fakeCarrier1",
                    varIDs: ['44285022994679']
                }
            };
            yield expect(shopOrderMethods.shipOrder('5505340965111', firstItemTrack)).not.to.be.rejected;
        }));
        it('Closes the order once all fulfillments are done', () => __awaiter(void 0, void 0, void 0, function* () {
            let goodReq = false;
            mocker.reset();
            mocker.get(/5505340965111.fulfillment_orders.json/, tanglyCases.twoItemFulfillmentTwoOpenOneNoShip.body);
            mocker.post(/./, (requestInfo) => __awaiter(void 0, void 0, void 0, function* () {
                let expected = '{"fulfillment":{"line_items_by_fulfillment_order":[{"fulfillment_order_id":6602711957751}],"tracking_info":{"number":"fakenum1","company":"fakeCarrier1"},"notify_customer":true}}';
                if (requestInfo.body !== expected) {
                    console.log(`url: ${requestInfo.url}`);
                    console.log(`body: ${requestInfo.body}`);
                    throw new Error("Bad Body");
                }
                goodReq = true;
                return { status: 201 };
            }));
            let firstItemTrack = {
                "1": {
                    trackingNumber: "fakenum1",
                    carrier: "fakeCarrier1",
                    varIDs: ['44285022994679']
                }
            };
            yield expect(shopOrderMethods.shipOrder('5505340965111', firstItemTrack)).not.to.be.rejected;
            expect(goodReq).to.be.true;
            let secondItemTrack = {
                "1": {
                    trackingNumber: "fakenum1",
                    carrier: "fakeCarrier1",
                    varIDs: ['44285022994679']
                },
                "2": {
                    trackingNumber: "fakenum2",
                    carrier: "DHL",
                    varIDs: ['44201046835447']
                },
                "noPkg": {
                    trackingNumber: null,
                    carrier: null,
                    varIDs: [55555555555],
                    unshippable: true
                }
            };
            let closed = false;
            let goodReq2 = false;
            let goodReq3 = false;
            mocker.reset();
            mocker.get(/5505340965111.fulfillment_orders.json/, tanglyCases.twoItemFulfillmentOneClosed.body);
            mocker.post(/./, (requestInfo) => __awaiter(void 0, void 0, void 0, function* () {
                if (requestInfo.url.match(/close/i)) {
                    closed = true;
                    return { status: 201 };
                }
                else if (requestInfo.url.match(/fulfillments/)) {
                    let expected = '{"fulfillment":{"line_items_by_fulfillment_order":[{"fulfillment_order_id":6602711990519}],"tracking_info":{"number":"fakenum2","company":"DHL"},"notify_customer":true}}';
                    let expected2 = '{"fulfillment":{"line_items_by_fulfillment_order":[{"fulfillment_order_id":666666}],"tracking_info":{"number":null,"company":null},"notify_customer":true}}';
                    if (requestInfo.body === expected) {
                        goodReq2 = true;
                    }
                    else if (requestInfo.body === expected2) {
                        goodReq3 = true;
                    }
                    else {
                        console.log(`url: ${requestInfo.url}`);
                        console.log(`body: ${requestInfo.body}`);
                        throw new Error("Bad Body");
                    }
                    return { status: 201 };
                }
                else {
                    console.log(`url: ${requestInfo.url}`);
                    console.log(`body: ${requestInfo.body}`);
                    throw new Error("Dunno");
                }
            }));
            yield expect(shopOrderMethods.shipOrder('5505340965111', secondItemTrack)).not.to.be.rejected;
            expect(goodReq2).to.be.true;
            expect(goodReq3).to.be.true;
            expect(closed).to.be.true;
        }));
        it(`Doesnt try to ship the same fulfillment line >1 time`, () => __awaiter(void 0, void 0, void 0, function* () {
            let redundantTracking = {
                "1": {
                    trackingNumber: "fakenum1",
                    carrier: "fakeCarrier1",
                    varIDs: ['44285022994679']
                },
                "2": {
                    trackingNumber: "fakenum2",
                    carrier: "fakeCarrier2",
                    varIDs: ['44285022994679']
                }
            };
            mocker.reset();
            mocker.get(/5505340965111.fulfillment_orders.json/, tanglyCases.twoItemFulfillmentTwoOpenOneNoShip.body);
            mocker.post(/./, (requestInfo) => __awaiter(void 0, void 0, void 0, function* () {
                if (requestInfo.body !== '{"fulfillment":{"line_items_by_fulfillment_order":[{"fulfillment_order_id":6602711957751}],"tracking_info":{"number":"fakenum1","company":"fakeCarrier1"},"notify_customer":true}}') {
                    console.log(`Bad req..`);
                    throw new Error("DIEEE");
                }
            }));
            yield expect(shopOrderMethods.shipOrder('5505340965111', redundantTracking)).not.to.be.rejected;
        }));
    }));
    context('Dealing with discounts', () => __awaiter(void 0, void 0, void 0, function* () {
        it('Works I guess', () => __awaiter(void 0, void 0, void 0, function* () {
            let expectedOrder = {
                shopId: '5517276610807',
                created: new Date("2024-02-02T23:47:09.000Z"),
                currency: 'USD',
                orderNumber: 'BlueDriverMAX1020',
                notes: null,
                orderStatusPage: 'https://shop.bluedrivermax.com/67512107255/orders/be3ffe78fe0766591662ac05ed6fa7af/authenticate?key=a0e4ea9865f24fc59618a2093ff098f7',
                isTest: false,
                discountCodes: [
                    { title: 'Discount 1', type: 'fixed_amount', amount: '75.0' },
                    { title: 'Discount 2', type: 'percentage', amount: '13.0' }
                ],
                source: 'web',
                customerId: '4564789913219',
                address: {
                    name: 'Ryan Cornelius',
                    addressOne: '6015 Scarlett Court',
                    addressTwo: null,
                    city: 'Dublin',
                    province: 'CA',
                    country: 'US',
                    postalCode: '94568',
                    phone: null,
                    email: 'asdsa@asdasd.com',
                    firstName: 'Ryan',
                    lastName: 'Cornelius',
                    company: 'Dublin hyundai'
                },
                items: [
                    {
                        lineId: '13784325947639',
                        qty: 1,
                        unitPrice: 999,
                        sku: '',
                        title: 'BlueDriver MAX Subscription',
                        variantId: '44201046835447',
                        variantTitle: null
                    },
                    {
                        lineId: '13784325980407',
                        qty: 1,
                        unitPrice: 0,
                        sku: '',
                        title: 'BlueDriver MAX',
                        variantId: '44284787949815',
                        variantTitle: null
                    }
                ],
                requestedShipping: 'Express',
                money: {
                    subTotal: 999,
                    tax: 92.15,
                    shipping: 0,
                    discount: 100,
                    total: 991.15
                }
            };
            let convertedOrder = shopConverter.shopOrderToNiceOrder(tanglyCases.discountOrder);
            expect(convertedOrder).to.deep.equal(expectedOrder);
        }));
    }));
}));
