var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import HttpRequestMock from 'http-request-mock';
import chai from 'chai';
import chaiAsPromised from "chai-as-promised";
const expect = chai.expect;
chai.use(chaiAsPromised);
import * as shopProds from '../shopify.products.js';
const mocker = HttpRequestMock.setup();
describe('Test products API', () => __awaiter(void 0, void 0, void 0, function* () {
    before(() => __awaiter(void 0, void 0, void 0, function* () {
        const productsResponse = {
            "products": [
                {
                    "id": 632910392,
                    "title": "IPod Nano - 8GB",
                    "body_html": "<p>It's the small iPod with one very big idea: Video. Now the world's most popular music player, available in 4GB and 8GB models, lets you enjoy TV shows, movies, video podcasts, and more. The larger, brighter display means amazing picture quality. In six eye-catching colors, iPod nano is stunning all around. And with models starting at just $149, little speaks volumes.</p>",
                    "vendor": "Apple",
                    "product_type": "Cult Products",
                    "created_at": "2023-07-11T17:47:36-04:00",
                    "handle": "ipod-nano",
                    "updated_at": "2023-07-11T17:47:36-04:00",
                    "published_at": "2007-12-31T19:00:00-05:00",
                    "template_suffix": null,
                    "published_scope": "web",
                    "tags": "Emotive, Flash Memory, MP3, Music",
                    "admin_graphql_api_id": "gid://shopify/Product/632910392",
                    "variants": [
                        {
                            "id": 808950810,
                            "product_id": 632910392,
                            "title": "Pink",
                            "price": "199.00",
                            "sku": "IPOD2008PINK",
                            "position": 1,
                            "inventory_policy": "continue",
                            "compare_at_price": null,
                            "fulfillment_service": "manual",
                            "inventory_management": "shopify",
                            "option1": "Pink",
                            "option2": null,
                            "option3": null,
                            "created_at": "2023-07-11T17:47:36-04:00",
                            "updated_at": "2023-07-11T17:47:36-04:00",
                            "taxable": true,
                            "barcode": "1234_pink",
                            "grams": 567,
                            "image_id": 562641783,
                            "weight": 1.25,
                            "weight_unit": "lb",
                            "inventory_item_id": 808950810,
                            "inventory_quantity": 10,
                            "old_inventory_quantity": 10,
                            "presentment_prices": [
                                {
                                    "price": {
                                        "amount": "199.00",
                                        "currency_code": "USD"
                                    },
                                    "compare_at_price": null
                                }
                            ],
                            "requires_shipping": true,
                            "admin_graphql_api_id": "gid://shopify/ProductVariant/808950810"
                        },
                        {
                            "id": 49148385,
                            "product_id": 632910392,
                            "title": "Red",
                            "price": "199.00",
                            "sku": "IPOD2008RED",
                            "position": 2,
                            "inventory_policy": "continue",
                            "compare_at_price": null,
                            "fulfillment_service": "manual",
                            "inventory_management": "shopify",
                            "option1": "Red",
                            "option2": null,
                            "option3": null,
                            "created_at": "2023-07-11T17:47:36-04:00",
                            "updated_at": "2023-07-11T17:47:36-04:00",
                            "taxable": true,
                            "barcode": "1234_red",
                            "grams": 567,
                            "image_id": null,
                            "weight": 1.25,
                            "weight_unit": "lb",
                            "inventory_item_id": 49148385,
                            "inventory_quantity": 20,
                            "old_inventory_quantity": 20,
                            "presentment_prices": [
                                {
                                    "price": {
                                        "amount": "199.00",
                                        "currency_code": "USD"
                                    },
                                    "compare_at_price": null
                                }
                            ],
                            "requires_shipping": true,
                            "admin_graphql_api_id": "gid://shopify/ProductVariant/49148385"
                        }
                    ],
                    "options": [
                        {
                            "id": 594680422,
                            "product_id": 632910392,
                            "name": "Color",
                            "position": 1,
                            "values": [
                                "Pink",
                                "Red",
                                "Green",
                                "Black"
                            ]
                        }
                    ],
                    "images": [
                        {
                            "id": 850703190,
                            "product_id": 632910392,
                            "position": 1,
                            "created_at": "2023-07-11T17:47:36-04:00",
                            "updated_at": "2023-07-11T17:47:36-04:00",
                            "alt": null,
                            "width": 123,
                            "height": 456,
                            "src": "https://cdn.shopify.com/s/files/1/0005/4838/0009/products/ipod-nano.png?v=1689112056",
                            "variant_ids": [],
                            "admin_graphql_api_id": "gid://shopify/ProductImage/850703190"
                        }
                    ],
                    "image": {
                        "id": 850703190,
                        "product_id": 632910392,
                        "position": 1,
                        "created_at": "2023-07-11T17:47:36-04:00",
                        "updated_at": "2023-07-11T17:47:36-04:00",
                        "alt": null,
                        "width": 123,
                        "height": 456,
                        "src": "https://cdn.shopify.com/s/files/1/0005/4838/0009/products/ipod-nano.png?v=1689112056",
                        "variant_ids": [],
                        "admin_graphql_api_id": "gid://shopify/ProductImage/850703190"
                    }
                },
                {
                    "id": 921728736,
                    "title": "IPod Touch 8GB",
                    "body_html": "<p>The iPod Touch has the iPhone's multi-touch interface, with a physical home button off the touch screen. The home screen has a list of buttons for the available applications.</p>",
                    "vendor": "Apple",
                    "product_type": "Cult Products",
                    "created_at": "2023-07-11T17:47:36-04:00",
                    "handle": "ipod-touch",
                    "updated_at": "2023-07-11T17:47:36-04:00",
                    "published_at": "2008-09-25T20:00:00-04:00",
                    "template_suffix": null,
                    "published_scope": "web",
                    "tags": "",
                    "admin_graphql_api_id": "gid://shopify/Product/921728736",
                    "variants": [
                        {
                            "id": 447654529,
                            "product_id": 921728736,
                            "title": "Black",
                            "price": "199.00",
                            "sku": "IPOD2009BLACK",
                            "position": 1,
                            "inventory_policy": "continue",
                            "compare_at_price": null,
                            "fulfillment_service": "shipwire-app",
                            "inventory_management": "shipwire-app",
                            "option1": "Black",
                            "option2": null,
                            "option3": null,
                            "created_at": "2023-07-11T17:47:36-04:00",
                            "updated_at": "2023-07-11T17:47:36-04:00",
                            "taxable": true,
                            "barcode": "1234_black",
                            "grams": 567,
                            "image_id": null,
                            "weight": 1.25,
                            "weight_unit": "lb",
                            "inventory_item_id": 447654529,
                            "inventory_quantity": 13,
                            "old_inventory_quantity": 13,
                            "presentment_prices": [
                                {
                                    "price": {
                                        "amount": "199.00",
                                        "currency_code": "USD"
                                    },
                                    "compare_at_price": null
                                }
                            ],
                            "requires_shipping": true,
                            "admin_graphql_api_id": "gid://shopify/ProductVariant/447654529"
                        }
                    ],
                    "options": [
                        {
                            "id": 891236591,
                            "product_id": 921728736,
                            "name": "Title",
                            "position": 1,
                            "values": [
                                "Black"
                            ]
                        }
                    ],
                    "images": [],
                    "image": null
                }
            ]
        };
        mocker.get(/\/products.json/, productsResponse);
    }));
    after(() => __awaiter(void 0, void 0, void 0, function* () {
        mocker.reset();
    }));
    context('Build product list', () => __awaiter(void 0, void 0, void 0, function* () {
        it('blahs', () => __awaiter(void 0, void 0, void 0, function* () {
            let productList = yield shopProds.getProductList();
            expect(productList).to.deep.equal({
                '49148385': {
                    mainId: '632910392',
                    mainTitle: 'IPod Nano - 8GB',
                    variantSKU: 'IPOD2008RED',
                    variantTitle: 'Red',
                    qty: 20
                },
                '447654529': {
                    mainId: '921728736',
                    mainTitle: 'IPod Touch 8GB',
                    variantSKU: 'IPOD2009BLACK',
                    variantTitle: 'Black',
                    qty: 13
                },
                '808950810': {
                    mainId: '632910392',
                    mainTitle: 'IPod Nano - 8GB',
                    variantSKU: 'IPOD2008PINK',
                    variantTitle: 'Pink',
                    qty: 10
                }
            });
        }));
    }));
}));
